<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>InfoPolylineArea</name>
    <message>
        <location filename="../InfoPolylineArea.js" line="+53"/>
        <source>Choose polyline</source>
        <translation>Izberite lomljenko</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Done</source>
        <translation>Končano</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Area</source>
        <translation>Območje</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Circumference</source>
        <translation>Obseg</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Polyline area:</source>
        <translation>Površina območja:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>circumference:</source>
        <translation>obseg:</translation>
    </message>
    <message>
        <location filename="../InfoPolylineAreaInit.js" line="+2"/>
        <source>Polyl&amp;ine Area</source>
        <translation>Območje &amp;lomljenke</translation>
    </message>
</context>
</TS>
